@@ -490,7 +490,7 @@ bool QOpen62541Subscription::convertWhereClause(const QOpcUaMonitoringParameters
             for (int j = 0; j < filter.whereClause().at(i).filterOperands().size(); ++j) {
                 UA_ExtensionObject_init(&result->elements[i].filterOperands[j]);
                 result->elements[i].filterOperands[j].encoding = UA_EXTENSIONOBJECT_DECODED;
-                const QVariant &currentOperand = filter.whereClause().at(i).filterOperands().at(j);
+                const QVariant currentOperand = filter.whereClause().at(i).filterOperands().at(j);
                 if (currentOperand.canConvert<QOpcUaElementOperand>()) {
                     UA_ElementOperand *op = UA_ElementOperand_new();
                     UA_ElementOperand_init(op);
@@ -667,11 +667,11 @@ bool QOpen62541Subscription::modifySubscriptionParameters(quint64 nodeHandle, QO
             emit m_backend->monitoringStatusChanged(nodeHandle, attr, item, p);
         } else {
             QOpcUaMonitoringParameters::Parameters changed = item;
-            if (!qFuzzyCompare(p.publishingInterval(), m_interval))
+            if (!qFuzzyCompare(res.revisedPublishingInterval, m_interval))
                 changed |= QOpcUaMonitoringParameters::Parameter::PublishingInterval;
-            if (p.lifetimeCount() != m_lifetimeCount)
+            if (res.revisedLifetimeCount != m_lifetimeCount)
                 changed |= QOpcUaMonitoringParameters::Parameter::LifetimeCount;
-            if (p.maxKeepAliveCount() != m_maxKeepaliveCount)
+            if (res.revisedMaxKeepAliveCount != m_maxKeepaliveCount)
                 changed |= QOpcUaMonitoringParameters::Parameter::MaxKeepAliveCount;
 
             m_lifetimeCount = res.revisedLifetimeCount;
